@@ -6,11 +6,13 @@
 import warnings
 from typing import Any
 
+import qcodes._version
 import qcodes.configuration as qcconfig
 from qcodes.logger.logger import conditionally_start_all_logging
-from qcodes.utils import add_to_spyder_UMR_excludelist
+from qcodes.utils.spyder_utils import add_to_spyder_UMR_excludelist
+
+__version__ = qcodes._version.__version__
 
-from ._version import __version__
 
 config: qcconfig.Config = qcconfig.Config()
 
@@ -53,7 +55,6 @@ from qcodes.instrument import (
     VisaInstrument,
     find_or_create_instrument,
 )
-from qcodes.instrument_drivers.test import test_instrument, test_instruments
 from qcodes.monitor import Monitor
 from qcodes.parameters import (
     ArrayParameter,
@@ -78,43 +79,12 @@ if config.core.import_legacy_api:
     from qcodes.utils import QCoDeSDeprecationWarning
 
     warnings.warn(
-        "import_legacy_api config option is deprecated and will be removed "
-        "in a future release please update your imports to import these "
-        "modules directly.",
+        "`core.import_legacy_api` and `gui.plotlib` config option has no effect "
+        "and will be removed in the future. "
+        "Please avoid setting this in your `qcodesrc.json` config file.",
         QCoDeSDeprecationWarning,
     )
 
-    plotlib = config.gui.plotlib
-    if plotlib in {"QT", "all"}:
-        try:
-            from qcodes.plots.pyqtgraph import QtPlot
-        except Exception:
-            print(
-                "pyqtgraph plotting not supported, "
-                'try "from qcodes.plots.pyqtgraph import QtPlot" '
-                "to see the full error"
-            )
-
-    if plotlib in {"matplotlib", "all"}:
-        try:
-            from qcodes.plots.qcmatplotlib import MatPlot
-        except Exception:
-            print(
-                "matplotlib plotting not supported, "
-                'try "from qcodes.plots.qcmatplotlib import MatPlot" '
-                "to see the full error"
-            )
-    from qcodes.actions import BreakIf, Task, Wait
-    from qcodes.data.data_array import DataArray
-    from qcodes.data.data_set import DataSet, load_data, new_data
-    from qcodes.data.format import Formatter
-    from qcodes.data.gnuplot_format import GNUPlotFormat
-    from qcodes.data.hdf5_format import HDF5Format
-    from qcodes.data.io import DiskIO
-    from qcodes.data.location import FormatLocation
-    from qcodes.loops import Loop, active_data_set, active_loop
-    from qcodes.measure import Measure
-
 
 try:
     _register_magic = config.core.get('register_magic', False)
