@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import time
-from typing import TYPE_CHECKING, Optional, Dict
+from typing import TYPE_CHECKING
 
-from qcodes.instrument.base import Instrument
-from qcodes.instrument.parameter import Parameter
+from qcodes.instrument import Instrument
+from qcodes.parameters import Parameter
 
 if TYPE_CHECKING:
     from qcodes.instrument_drivers.tektronix.Keithley_2600_channels import Keithley_2600
@@ -33,7 +33,7 @@ def calibrate_keithley_smu_v(
     src_Z: float = 1e-30,
     time_delay: float = 3.0,
     save_calibrations: bool = False,
-    dmm_range_per_smu_range_mapping: Optional[Dict[str, float]] = None
+    dmm_range_per_smu_range_mapping: dict[str, float] | None = None,
 ) -> None:
     if dmm_range_per_smu_range_mapping is None:
         dmm_range_per_smu_range_mapping = {
