@@ -1,12 +1,18 @@
+from __future__ import annotations
+
 from typing import Any, cast
 
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 
 from .versioning.converters import new_to_old, old_to_new
-from .versioning.rundescribertypes import (RunDescriberDicts,
-                                           RunDescriberV0Dict,
-                                           RunDescriberV1Dict,
-                                           RunDescriberV2Dict)
+from .versioning.rundescribertypes import (
+    RunDescriberDicts,
+    RunDescriberV0Dict,
+    RunDescriberV1Dict,
+    RunDescriberV2Dict,
+    RunDescriberV3Dict,
+    Shapes,
+)
 
 from.versioning.v0 import InterDependencies
 
@@ -24,37 +30,49 @@ class RunDescriber:
     attributes when converting itself to dictionary.
     """
 
-    def __init__(self, interdeps: InterDependencies_) -> None:
+    def __init__(
+        self, interdeps: InterDependencies_, shapes: Shapes | None = None
+    ) -> None:
 
         if not isinstance(interdeps, InterDependencies_):
             raise ValueError('The interdeps arg must be of type: '
                              'InterDependencies_. '
                              f'Got {type(interdeps)}.')
 
-        self.interdeps = interdeps
+        self._interdeps = interdeps
 
-        self._version = 2
+        self._shapes = shapes
+        self._version = 3
 
     @property
     def version(self) -> int:
         return self._version
 
-    def _to_dict(self) -> RunDescriberV2Dict:
+    @property
+    def shapes(self) -> Shapes | None:
+        return self._shapes
+
+    @property
+    def interdeps(self) -> InterDependencies_:
+        return self._interdeps
+
+    def _to_dict(self) -> RunDescriberV3Dict:
         """
         Convert this object into a dictionary. This method is intended to
         be used only by the serialization routines.
         """
-        ser: RunDescriberV2Dict = {
+        ser: RunDescriberV3Dict = {
             'version': self._version,
             'interdependencies': new_to_old(self.interdeps)._to_dict(),
-            'interdependencies_': self.interdeps._to_dict()
+            'interdependencies_': self.interdeps._to_dict(),
+            'shapes': self.shapes
 
         }
 
         return ser
 
     @classmethod
-    def _from_dict(cls, ser: RunDescriberDicts) -> 'RunDescriber':
+    def _from_dict(cls, ser: RunDescriberDicts) -> RunDescriber:
         """
         Make a RunDescriber object from a dictionary. This method is
         intended to be used only by the deserialization routines.
@@ -71,11 +89,17 @@ class RunDescriber:
             rundesc = cls(
                 InterDependencies_._from_dict(ser['interdependencies'])
             )
-        elif ser['version'] >= 2:
+        elif ser['version'] == 2:
             ser = cast(RunDescriberV2Dict, ser)
             rundesc = cls(
                 InterDependencies_._from_dict(ser['interdependencies_'])
             )
+        elif ser['version'] >= 3:
+            ser = cast(RunDescriberV3Dict, ser)
+            rundesc = cls(
+                InterDependencies_._from_dict(ser['interdependencies_']),
+                shapes=ser['shapes']
+            )
         else:
             raise RuntimeError(f"Unknown version: "
                                f"Cannot deserialize from {ser['version']}")
@@ -87,7 +111,9 @@ class RunDescriber:
             return False
         if self.interdeps != other.interdeps:
             return False
+        if self.shapes != other.shapes:
+            return False
         return True
 
     def __repr__(self) -> str:
-        return f"RunDescriber({self.interdeps})"
+        return f"RunDescriber({self.interdeps}, Shapes: {self._shapes})"
