@@ -1,22 +1,27 @@
+from __future__ import annotations
+
 import json
 import logging
-from collections import defaultdict
-from typing import Dict, DefaultDict, List, Sequence, Tuple
 import sys
+from collections import defaultdict
+from typing import DefaultDict, Mapping, Sequence
 
 from tqdm import tqdm
 
-from qcodes.dataset.sqlite.connection import ConnectionPlus, transaction, \
-    atomic, atomic_transaction
-from qcodes.dataset.sqlite.query_helpers import one
 from qcodes.dataset.descriptions.param_spec import ParamSpec
 from qcodes.dataset.descriptions.versioning.v0 import InterDependencies
-
+from qcodes.dataset.sqlite.connection import (
+    ConnectionPlus,
+    atomic,
+    atomic_transaction,
+    transaction,
+)
+from qcodes.dataset.sqlite.query_helpers import get_description_map, one
 
 log = logging.getLogger(__name__)
 
 
-def _2to3_get_result_tables(conn: ConnectionPlus) -> Dict[int, str]:
+def _2to3_get_result_tables(conn: ConnectionPlus) -> dict[int, str]:
     rst_query = "SELECT run_id, result_table_name FROM runs"
     cur = conn.cursor()
     cur.execute(rst_query)
@@ -24,12 +29,12 @@ def _2to3_get_result_tables(conn: ConnectionPlus) -> Dict[int, str]:
     data = cur.fetchall()
     cur.close()
     results = {}
-    for row in data:
-        results[row['run_id']] = row['result_table_name']
+    for run_id, result_table_name in data:
+        results[run_id] = result_table_name
     return results
 
 
-def _2to3_get_layout_ids(conn: ConnectionPlus) -> DefaultDict[int, List[int]]:
+def _2to3_get_layout_ids(conn: ConnectionPlus) -> DefaultDict[int, list[int]]:
     query = """
             select runs.run_id, layouts.layout_id
             FROM layouts
@@ -40,17 +45,15 @@ def _2to3_get_layout_ids(conn: ConnectionPlus) -> DefaultDict[int, List[int]]:
     data = cur.fetchall()
     cur.close()
 
-    results: DefaultDict[int, List[int]] = defaultdict(list)
+    results: DefaultDict[int, list[int]] = defaultdict(list)
 
-    for row in data:
-        run_id = row['run_id']
-        layout_id = row['layout_id']
+    for run_id, layout_id in data:
         results[run_id].append(layout_id)
 
     return results
 
 
-def _2to3_get_indeps(conn: ConnectionPlus) -> DefaultDict[int, List[int]]:
+def _2to3_get_indeps(conn: ConnectionPlus) -> DefaultDict[int, list[int]]:
     query = """
             SELECT layouts.run_id, layouts.layout_id
             FROM layouts
@@ -61,17 +64,15 @@ def _2to3_get_indeps(conn: ConnectionPlus) -> DefaultDict[int, List[int]]:
     cur.execute(query)
     data = cur.fetchall()
     cur.close()
-    results: DefaultDict[int, List[int]] = defaultdict(list)
+    results: DefaultDict[int, list[int]] = defaultdict(list)
 
-    for row in data:
-        run_id = row['run_id']
-        layout_id = row['layout_id']
+    for run_id, layout_id in data:
         results[run_id].append(layout_id)
 
     return results
 
 
-def _2to3_get_deps(conn: ConnectionPlus) -> DefaultDict[int, List[int]]:
+def _2to3_get_deps(conn: ConnectionPlus) -> DefaultDict[int, list[int]]:
     query = """
             SELECT layouts.run_id, layouts.layout_id
             FROM layouts
@@ -82,18 +83,15 @@ def _2to3_get_deps(conn: ConnectionPlus) -> DefaultDict[int, List[int]]:
     cur.execute(query)
     data = cur.fetchall()
     cur.close()
-    results: DefaultDict[int, List[int]] = defaultdict(list)
+    results: DefaultDict[int, list[int]] = defaultdict(list)
 
-    for row in data:
-        run_id = row['run_id']
-        layout_id = row['layout_id']
+    for run_id, layout_id in data:
         results[run_id].append(layout_id)
 
     return results
 
 
-def _2to3_get_dependencies(conn: ConnectionPlus
-                           ) -> DefaultDict[int, List[int]]:
+def _2to3_get_dependencies(conn: ConnectionPlus) -> DefaultDict[int, list[int]]:
     query = """
             SELECT dependent, independent
             FROM dependencies
@@ -103,21 +101,18 @@ def _2to3_get_dependencies(conn: ConnectionPlus
     cur.execute(query)
     data = cur.fetchall()
     cur.close()
-    results: DefaultDict[int, List[int]] = defaultdict(list)
+    results: DefaultDict[int, list[int]] = defaultdict(list)
 
     if len(data) == 0:
         return results
 
-    for row in data:
-        dep = row['dependent']
-        indep = row['independent']
+    for dep, indep in data:
         results[dep].append(indep)
 
     return results
 
 
-def _2to3_get_layouts(conn: ConnectionPlus) -> Dict[int,
-                                                    Tuple[str, str, str, str]]:
+def _2to3_get_layouts(conn: ConnectionPlus) -> dict[int, tuple[str, str, str, str]]:
     query = """
             SELECT layout_id, parameter, label, unit, inferred_from
             FROM layouts
@@ -125,24 +120,23 @@ def _2to3_get_layouts(conn: ConnectionPlus) -> Dict[int,
     cur = conn.cursor()
     cur.execute(query)
 
-    results: Dict[int, Tuple[str, str, str, str]] = {}
-    for row in cur.fetchall():
-        results[row['layout_id']] = (row['parameter'],
-                                     row['label'],
-                                     row['unit'],
-                                     row['inferred_from'])
+    results: dict[int, tuple[str, str, str, str]] = {}
+    for layout_id, parameter, label, unit, inferred_from in cur.fetchall():
+        results[layout_id] = (parameter, label, unit, inferred_from)
     return results
 
 
-def _2to3_get_paramspecs(conn: ConnectionPlus,
-                         layout_ids: List[int],
-                         layouts: Dict[int, Tuple[str, str, str, str]],
-                         dependencies: Dict[int, List[int]],
-                         deps: Sequence[int],
-                         indeps: Sequence[int],
-                         result_table_name: str) -> Dict[int, ParamSpec]:
+def _2to3_get_paramspecs(
+    conn: ConnectionPlus,
+    layout_ids: list[int],
+    layouts: Mapping[int, tuple[str, str, str, str]],
+    dependencies: Mapping[int, Sequence[int]],
+    deps: Sequence[int],
+    indeps: Sequence[int],
+    result_table_name: str,
+) -> dict[int, ParamSpec]:
 
-    paramspecs: Dict[int, ParamSpec] = {}
+    paramspecs: dict[int, ParamSpec] = {}
 
     the_rest = set(layout_ids).difference(set(deps).union(set(indeps)))
 
@@ -154,17 +148,18 @@ def _2to3_get_paramspecs(conn: ConnectionPlus,
         # get the data type
         sql = f'PRAGMA TABLE_INFO("{result_table_name}")'
         c = transaction(conn, sql)
+        description = get_description_map(c)
         paramtype = None
         for row in c.fetchall():
-            if row['name'] == name:
-                paramtype = row['type']
+            if row[description["name"]] == name:
+                paramtype = row[description["type"]]
                 break
         if paramtype is None:
             raise TypeError(f"Could not determine type of {name} during the"
                             f"db upgrade of {result_table_name}")
 
-        inferred_from: List[str] = []
-        depends_on: List[str] = []
+        inferred_from: list[str] = []
+        depends_on: list[str] = []
 
         # this parameter depends on another parameter
         if layout_id in deps:
@@ -184,7 +179,7 @@ def _2to3_get_paramspecs(conn: ConnectionPlus,
     return paramspecs
 
 
-def upgrade_2_to_3(conn: ConnectionPlus) -> None:
+def upgrade_2_to_3(conn: ConnectionPlus, show_progress_bar: bool = True) -> None:
     """
     Perform the upgrade from version 2 to version 3
 
@@ -212,7 +207,9 @@ def upgrade_2_to_3(conn: ConnectionPlus) -> None:
         layouts = _2to3_get_layouts(conn)
         dependencies = _2to3_get_dependencies(conn)
 
-        pbar = tqdm(range(1, no_of_runs+1), file=sys.stdout)
+        pbar = tqdm(
+            range(1, no_of_runs + 1), file=sys.stdout, disable=not show_progress_bar
+        )
         pbar.set_description("Upgrading database; v2 -> v3")
 
         for run_id in pbar:
