@@ -2,31 +2,51 @@
 This module provides a number of convenient general-purpose functions that
 are useful for building more database-specific queries out of them.
 """
+from __future__ import annotations
+
 import itertools
 import sqlite3
-from distutils.version import LooseVersion
-
-from typing import List, Any, Union, Dict, Tuple, Optional, Sequence
+from typing import Any, List, Mapping, Sequence, Union
 
 import numpy as np
 from numpy import ndarray
+from packaging import version
 
-from qcodes.dataset.sqlite.connection import ConnectionPlus, \
-    atomic_transaction, transaction, atomic
+from qcodes.dataset.sqlite.connection import (
+    ConnectionPlus,
+    atomic,
+    atomic_transaction,
+    transaction,
+)
 from qcodes.dataset.sqlite.settings import SQLiteSettings
-from qcodes.utils.deprecate import deprecate
-
+from qcodes.utils import deprecate
 
 # represent the type of  data we can/want map to sqlite column
 VALUE = Union[str, complex, List, ndarray, bool, None]
-VALUES = List[VALUE]
+VALUES = Sequence[VALUE]
 
 
-def one(curr: sqlite3.Cursor, column: Union[int, str]) -> Any:
+def get_description_map(curr: sqlite3.Cursor) -> dict[str, int]:
+    """Get the description of the last query
+    Args:
+        curr: last cursor operated on
+
+    Returns:
+        dictionary mapping column names and their indices
+    """
+    return {c[0]: i for i, c in enumerate(curr.description)}
+
+
+def one(curr: sqlite3.Cursor, column: int | str) -> Any:
     """Get the value of one column from one row
+
     Args:
         curr: cursor to operate on
-        column: name of the column
+        column: name of the column or the index of the desired column in the
+            result rows that ``cursor.fetchall()`` returns. In case a
+            column name is being passed, it is important that the casing
+            of the column name is exactly the one used when the column was
+            created.
 
     Returns:
         the value
@@ -37,10 +57,41 @@ def one(curr: sqlite3.Cursor, column: Union[int, str]) -> Any:
     elif len(res) == 0:
         raise RuntimeError("Expected one row")
     else:
-        return res[0][column]
+        row = res[0]
+
+        if isinstance(column, int):
+            column_index_in_the_row = column
+        else:
+            columns_name_to_index_map = get_description_map(curr)
+            maybe_column_index = columns_name_to_index_map.get(column)
+            if maybe_column_index is not None:
+                column_index_in_the_row = maybe_column_index
+            else:
+                # Note that the error message starts the same way as an
+                # sqlite3 error about a column not existing:
+                # ``no such column: <column name>`` - this is on purpose,
+                # because if the given column name is not found in the
+                # description map from the cursor then something is
+                # definitely wrong, and likely the requested column does not
+                # exist or the casing of its name is not equal to the casing
+                # in the database
+                raise RuntimeError(
+                    f"no such column: {column}. "
+                    f"Valid columns are {tuple(columns_name_to_index_map.keys())}"
+                )
+
+        return row[column_index_in_the_row]
 
 
-def many(curr: sqlite3.Cursor, *columns: str) -> List[Any]:
+def _need_to_select(curr: sqlite3.Cursor, *columns: str) -> bool:
+    """
+    Return True if the columns' description of the last query doesn't exactly match,
+    the order is important
+    """
+    return tuple(c[0] for c in curr.description) != columns
+
+
+def many(curr: sqlite3.Cursor, *columns: str) -> tuple[Any, ...]:
     """Get the values of many columns from one row
     Args:
         curr: cursor to operate on
@@ -52,11 +103,16 @@ def many(curr: sqlite3.Cursor, *columns: str) -> List[Any]:
     res = curr.fetchall()
     if len(res) > 1:
         raise RuntimeError("Expected only one row")
+    elif _need_to_select(curr, *columns):
+        raise RuntimeError(
+            "Expected consistent selection: cursor has columns "
+            f"{tuple(c[0] for c in curr.description)} but expected {columns}"
+        )
     else:
-        return [res[0][c] for c in columns]
+        return res[0]
 
 
-def many_many(curr: sqlite3.Cursor, *columns: str) -> List[List[Any]]:
+def many_many(curr: sqlite3.Cursor, *columns: str) -> list[tuple[Any, ...]]:
     """Get all values of many columns
     Args:
         curr: cursor to operate on
@@ -66,14 +122,39 @@ def many_many(curr: sqlite3.Cursor, *columns: str) -> List[List[Any]]:
         list of lists of values
     """
     res = curr.fetchall()
-    results = []
-    for r in res:
-        results.append([r[c] for c in columns])
-    return results
+
+    if _need_to_select(curr, *columns):
+        raise RuntimeError(
+            "Expected consistent selection: cursor has columns "
+            f"{tuple(c[0] for c in curr.description)} but expected {columns}"
+        )
+
+    return res
 
 
-def select_one_where(conn: ConnectionPlus, table: str, column: str,
-                     where_column: str, where_value: Any) -> Any:
+def select_one_where(
+    conn: ConnectionPlus, table: str, column: str, where_column: str, where_value: VALUE
+) -> VALUE:
+    """
+    Select a value from a given column given a match of a value in a
+    different column. If the given matched row/column intersect is empty
+    None will be returned.
+
+    Args:
+        conn: Connection to the db
+        table: Table to look for values in
+        column: Column to return value from, it is important that the casing
+            of the column name is exactly the one used when the column was
+            created
+        where_column: Column to match on
+        where_value: Value to match in where_column
+
+    Returns:
+        Value found
+
+    Raises:
+        RuntimeError if not exactly one match is found.
+    """
     query = f"""
     SELECT {column}
     FROM
@@ -86,8 +167,13 @@ def select_one_where(conn: ConnectionPlus, table: str, column: str,
     return res
 
 
-def select_many_where(conn: ConnectionPlus, table: str, *columns: str,
-                      where_column: str, where_value: Any) -> Any:
+def select_many_where(
+    conn: ConnectionPlus,
+    table: str,
+    *columns: str,
+    where_column: str,
+    where_value: VALUE,
+) -> VALUES:
     _columns = ",".join(columns)
     query = f"""
     SELECT {_columns}
@@ -101,7 +187,7 @@ def select_many_where(conn: ConnectionPlus, table: str, *columns: str,
     return res
 
 
-def _massage_dict(metadata: Dict[str, Any]) -> Tuple[str, List[Any]]:
+def _massage_dict(metadata: Mapping[str, Any]) -> tuple[str, list[Any]]:
     """
     {key:value, key2:value} -> ["key=?, key2=?", [value, value]]
     """
@@ -127,11 +213,12 @@ def update_where(conn: ConnectionPlus, table: str,
     atomic_transaction(conn, query, *values, where_value)
 
 
-def insert_values(conn: ConnectionPlus,
-                  formatted_name: str,
-                  columns: List[str],
-                  values: VALUES,
-                  ) -> int:
+def insert_values(
+    conn: ConnectionPlus,
+    formatted_name: str,
+    columns: list[str],
+    values: VALUES,
+) -> int:
     """
     Inserts values for the specified columns.
     Will pad with null if not all parameters are specified.
@@ -146,7 +233,10 @@ def insert_values(conn: ConnectionPlus,
     """
 
     c = atomic_transaction(conn, query, *values)
-    return c.lastrowid
+    return_value = c.lastrowid
+    if return_value is None:
+        raise RuntimeError(f"Insert_values into {formatted_name} failed")
+    return return_value
 
 
 def insert_many_values(conn: ConnectionPlus,
@@ -178,13 +268,13 @@ def insert_many_values(conn: ConnectionPlus,
     # Version check cf.
     # "https://stackoverflow.com/questions/9527851/sqlite-error-
     #  too-many-terms-in-compound-select"
-    version = SQLiteSettings.settings['VERSION']
+    version_str = SQLiteSettings.settings["VERSION"]
 
     # According to the SQLite changelog, the version number
     # to check against below
     # ought to be 3.7.11, but that fails on Travis
-    if LooseVersion(str(version)) <= LooseVersion('3.8.2'):
-        max_var = SQLiteSettings.limits['MAX_COMPOUND_SELECT']
+    if version.parse(str(version_str)) <= version.parse("3.8.2"):
+        max_var = SQLiteSettings.limits["MAX_COMPOUND_SELECT"]
     else:
         max_var = SQLiteSettings.limits['MAX_VARIABLE_NUMBER']
     rows_per_transaction = int(int(max_var)/no_of_columns)
@@ -220,16 +310,19 @@ def insert_many_values(conn: ConnectionPlus,
                 return_value = c.lastrowid
             start += chunk
 
+    if return_value is None:
+        raise RuntimeError(f"insert_many_values into {formatted_name} failed ")
     return return_value
 
 
-@deprecate('Unused private method to be removed in a future version')
-def modify_values(conn: ConnectionPlus,
-                  formatted_name: str,
-                  index: int,
-                  columns: List[str],
-                  values: VALUES,
-                  ) -> int:
+@deprecate("Unused private method to be removed in a future version")
+def modify_values(
+    conn: ConnectionPlus,
+    formatted_name: str,
+    index: int,
+    columns: list[str],
+    values: VALUES,
+) -> int:
     """
     Modify values for the specified columns.
     If a column is in the table but not in the columns list is
@@ -251,13 +344,14 @@ def modify_values(conn: ConnectionPlus,
     return c.rowcount
 
 
-@deprecate('Unused private method to be removed in a future version')
-def modify_many_values(conn: ConnectionPlus,
-                       formatted_name: str,
-                       start_index: int,
-                       columns: List[str],
-                       list_of_values: List[VALUES],
-                       ) -> None:
+@deprecate("Unused private method to be removed in a future version")
+def modify_many_values(
+    conn: ConnectionPlus,
+    formatted_name: str,
+    start_index: int,
+    columns: list[str],
+    list_of_values: list[VALUES],
+) -> None:
     """
     Modify many values for the specified columns.
     If a column is in the table but not in the column list is
@@ -300,8 +394,9 @@ def length(conn: ConnectionPlus,
         return _len
 
 
-def insert_column(conn: ConnectionPlus, table: str, name: str,
-                  paramtype: Optional[str] = None) -> None:
+def insert_column(
+    conn: ConnectionPlus, table: str, name: str, paramtype: str | None = None
+) -> None:
     """Insert new column to a table
 
     Args:
@@ -314,8 +409,9 @@ def insert_column(conn: ConnectionPlus, table: str, name: str,
     # and do nothing if it is
     query = f'PRAGMA TABLE_INFO("{table}");'
     cur = atomic_transaction(conn, query)
-    columns = many_many(cur, "name")
-    if name in [col[0] for col in columns]:
+    description = get_description_map(cur)
+    columns = cur.fetchall()
+    if name in [col[description["name"]] for col in columns]:
         return
 
     with atomic(conn) as conn:
@@ -341,8 +437,9 @@ def is_column_in_table(conn: ConnectionPlus, table: str, column: str) -> bool:
         column: the column name
     """
     cur = atomic_transaction(conn, f"PRAGMA table_info({table})")
+    description = get_description_map(cur)
     for row in cur.fetchall():
-        if row['name'] == column:
+        if row[description["name"]] == column:
             return True
     return False
 
