@@ -1,18 +1,24 @@
 import re
-from typing import Any, Optional, Sequence, Union
+from typing import Any, Literal, Optional, Sequence, Union
 
 import numpy as np
 from pyvisa import VisaIOError
 from pyvisa.constants import StatusCode
-from typing_extensions import Literal
 
-from qcodes import validators as vals
-from qcodes.instrument import VisaInstrument
-from qcodes.instrument.base import InstrumentBase
-from qcodes.instrument.channel import ChannelList, InstrumentChannel, InstrumentModule
-from qcodes.instrument.parameter import Parameter, ParameterWithSetpoints
-from qcodes.utils.deprecate import deprecate
-from qcodes.utils.helpers import create_on_off_val_mapping
+import qcodes.validators as vals
+from qcodes.instrument import (
+    ChannelList,
+    InstrumentBase,
+    InstrumentChannel,
+    InstrumentModule,
+    VisaInstrument,
+)
+from qcodes.parameters import (
+    Parameter,
+    ParameterWithSetpoints,
+    create_on_off_val_mapping,
+)
+from qcodes.utils import deprecate
 
 
 class DSOTimeAxisParam(Parameter):
