@@ -1,84 +1,119 @@
-from typing import Sequence, Union, Any
-import time
 import re
-import logging
+import time
+from typing import Any, Sequence, Union
 
 import numpy as np
-from pyvisa import VisaIOError, errors
-from qcodes import (VisaInstrument, InstrumentChannel, ArrayParameter,
-                    ChannelList)
-from qcodes.utils.validators import Ints, Numbers, Enum, Bool
+from pyvisa import constants, errors
 
-logger = logging.getLogger()
-
-class PNASweep(ArrayParameter):
-    def __init__(self,
-                 name: str,
-                 instrument: 'PNABase',
-                 **kwargs: Any) -> None:
-
-        super().__init__(name,
-                         instrument=instrument,
-                         shape=(0,),
-                         setpoints=((0,),),
-                         **kwargs)
-
-    @property  # type: ignore[override]
-    def shape(self) -> Sequence[int]:  # type: ignore[override]
-        if self._instrument is None:
-            return (0,)
-        return (self._instrument.root_instrument.points(),)
-
-    @shape.setter
-    def shape(self, val: Sequence[int]) -> None:
-        pass
-
-    @property  # type: ignore[override]
-    def setpoints(self) -> Sequence[np.ndarray]:  # type: ignore[override]
-        if self._instrument is None:
-            raise RuntimeError("Cannot return setpoints if not attached "
-                               "to instrument")
-        start = self._instrument.root_instrument.start()
-        stop = self._instrument.root_instrument.stop()
-        return (np.linspace(start, stop, self.shape[0]),)
-
-    @setpoints.setter
-    def setpoints(self, val: Sequence[int]) -> None:
-        pass
+from qcodes.instrument import ChannelList, InstrumentChannel, VisaInstrument
+from qcodes.parameters import (
+    Parameter,
+    ParameterBase,
+    ParameterWithSetpoints,
+    create_on_off_val_mapping,
+)
+from qcodes.validators import Arrays, Bool, Enum, Ints, Numbers
 
 
-class FormattedSweep(PNASweep):
+class PNAAxisParameter(Parameter):
+    def __init__(
+        self,
+        startparam: Parameter,
+        stopparam: Parameter,
+        pointsparam: Parameter,
+        **kwargs: Any,
+    ):
+        """
+        Axis parameter for traces from the PNA
+        """
+        super().__init__(**kwargs)
+
+        self._startparam = startparam
+        self._stopparam = stopparam
+        self._pointsparam = pointsparam
+
+    def get_raw(self) -> np.ndarray:
+        """
+        Return the axis values, with values retrieved from the parent instrument
+        """
+        return np.linspace(self._startparam(), self._stopparam(), self._pointsparam())
+
+
+class PNALogAxisParamter(PNAAxisParameter):
+    def get_raw(self) -> np.ndarray:
+        """
+        Return the axis values on a log scale, with values retrieved from
+        the parent instrument
+        """
+        return np.geomspace(self._startparam(), self._stopparam(), self._pointsparam())
+
+
+class PNATimeAxisParameter(PNAAxisParameter):
+    def get_raw(self) -> np.ndarray:
+        """
+        Return the axis values on a time scale, with values retrieved from
+        the parent instrument
+        """
+        return np.linspace(0, self._stopparam(), self._pointsparam())
+
+
+class FormattedSweep(ParameterWithSetpoints):
     """
     Mag will run a sweep, including averaging, before returning data.
     As such, wait time in a loop is not needed.
     """
-    def __init__(self,
-                 name: str,
-                 instrument: 'PNABase',
-                 sweep_format: str,
-                 label: str,
-                 unit: str,
-                 memory: bool = False) -> None:
-        super().__init__(name,
-                         instrument=instrument,
-                         label=label,
-                         unit=unit,
-                         setpoint_names=('frequency',),
-                         setpoint_labels=('Frequency',),
-                         setpoint_units=('Hz',)
-                         )
+
+    def __init__(
+        self,
+        name: str,
+        instrument: "PNABase",
+        sweep_format: str,
+        label: str,
+        unit: str,
+        memory: bool = False,
+        **kwargs: Any,
+    ) -> None:
+        super().__init__(name, instrument=instrument, label=label, unit=unit, **kwargs)
         self.sweep_format = sweep_format
         self.memory = memory
 
+    @property
+    def setpoints(self) -> Sequence[ParameterBase]:
+        """
+        Overwrite setpoint parameter to ask the PNA what type of sweep
+        """
+        if self.instrument is None:
+            raise RuntimeError(
+                "Cannot return setpoints if not attached " "to instrument"
+            )
+        root_instrument: "PNABase" = self.root_instrument  # type: ignore[assignment]
+        sweep_type = root_instrument.sweep_type()
+        if sweep_type == "LIN":
+            return (root_instrument.frequency_axis,)
+        elif sweep_type == "LOG":
+            return (root_instrument.frequency_log_axis,)
+        elif sweep_type == "CW":
+            return (root_instrument.time_axis,)
+        else:
+            raise NotImplementedError(f"Axis for type {sweep_type} not implemented yet")
+
+    @setpoints.setter
+    def setpoints(self, val: Any) -> None:
+        """
+        Stub to allow initialization. Ignore any set attempts on setpoint as we
+        figure it out on the fly.
+        """
+        return
+
     def get_raw(self) -> Sequence[float]:
-        if self._instrument is None:
+        if self.instrument is None:
             raise RuntimeError("Cannot get data without instrument")
-        root_instr = self._instrument.root_instrument
+        root_instr = self.instrument.root_instrument
         # Check if we should run a new sweep
         if root_instr.auto_sweep():
-            prev_mode = self._instrument.run_sweep()
+            prev_mode = self.instrument.run_sweep()
         # Ask for data, setting the format to the requested form
-        self._instrument.format(self.sweep_format)
+        self.instrument.format(self.sweep_format)
         data = root_instr.visa_handle.query_binary_values('CALC:DATA? FDATA',
                                                           datatype='f',
                                                           is_big_endian=True)
@@ -96,13 +131,16 @@ class PNAPort(InstrumentChannel):
     Note: This can be expanded to include a large number of extra parameters...
     """
 
-    def __init__(self,
-                 parent: 'PNABase',
-                 name: str,
-                 port: int,
-                 min_power: Union[int, float],
-                 max_power: Union[int, float]) -> None:
-        super().__init__(parent, name)
+    def __init__(
+        self,
+        parent: "PNABase",
+        name: str,
+        port: int,
+        min_power: Union[int, float],
+        max_power: Union[int, float],
+        **kwargs: Any,
+    ) -> None:
+        super().__init__(parent, name, **kwargs)
 
         self.port = int(port)
         if self.port < 1 or self.port > 4:
@@ -133,12 +171,15 @@ class PNATrace(InstrumentChannel):
     Allow operations on individual PNA traces.
     """
 
-    def __init__(self,
-                 parent: 'PNABase',
-                 name: str,
-                 trace_name: str,
-                 trace_num: int) -> None:
-        super().__init__(parent, name)
+    def __init__(
+        self,
+        parent: "PNABase",
+        name: str,
+        trace_name: str,
+        trace_num: int,
+        **kwargs: Any,
+    ) -> None:
+        super().__init__(parent, name, **kwargs)
         self.trace_name = trace_name
         self.trace_num = trace_num
 
@@ -151,49 +192,89 @@ class PNATrace(InstrumentChannel):
         # Note: Currently parameters that return complex values are not
         # supported as there isn't really a good way of saving them into the
         # dataset
-        self.add_parameter('format',
-                           label='Format',
-                           get_cmd='CALC:FORM?',
-                           set_cmd='CALC:FORM {}',
-                           vals=Enum('MLIN', 'MLOG', 'PHAS',
-                                     'UPH', 'IMAG', 'REAL'))
+        self.add_parameter(
+            "format",
+            label="Format",
+            get_cmd="CALC:FORM?",
+            set_cmd="CALC:FORM {}",
+            vals=Enum("MLIN", "MLOG", "PHAS", "UPH", "IMAG", "REAL", "POLAR"),
+        )
 
         # And a list of individual formats
-        self.add_parameter('magnitude',
-                           sweep_format='MLOG',
-                           label='Magnitude',
-                           unit='dB',
-                           parameter_class=FormattedSweep)
-        self.add_parameter('linear_magnitude',
-                           sweep_format='MLIN',
-                           label='Magnitude',
-                           unit='ratio',
-                           parameter_class=FormattedSweep)
-        self.add_parameter('phase',
-                           sweep_format='PHAS',
-                           label='Phase',
-                           unit='deg',
-                           parameter_class=FormattedSweep)
-        self.add_parameter('unwrapped_phase',
-                           sweep_format='UPH',
-                           label='Phase',
-                           unit='deg',
-                           parameter_class=FormattedSweep)
-        self.add_parameter("group_delay",
-                           sweep_format='GDEL',
-                           label='Group Delay',
-                           unit='s',
-                           parameter_class=FormattedSweep)
-        self.add_parameter('real',
-                           sweep_format='REAL',
-                           label='Real',
-                           unit='LinMag',
-                           parameter_class=FormattedSweep)
-        self.add_parameter('imaginary',
-                           sweep_format='IMAG',
-                           label='Imaginary',
-                           unit='LinMag',
-                           parameter_class=FormattedSweep)
+        self.add_parameter(
+            "magnitude",
+            sweep_format="MLOG",
+            label="Magnitude",
+            unit="dB",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "linear_magnitude",
+            sweep_format="MLIN",
+            label="Magnitude",
+            unit="ratio",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "phase",
+            sweep_format="PHAS",
+            label="Phase",
+            unit="deg",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "unwrapped_phase",
+            sweep_format="UPH",
+            label="Phase",
+            unit="deg",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "group_delay",
+            sweep_format="GDEL",
+            label="Group Delay",
+            unit="s",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "real",
+            sweep_format="REAL",
+            label="Real",
+            unit="LinMag",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "imaginary",
+            sweep_format="IMAG",
+            label="Imaginary",
+            unit="LinMag",
+            parameter_class=FormattedSweep,
+            vals=Arrays(shape=(self.parent.points,)),
+        )
+        self.add_parameter(
+            "polar",
+            sweep_format="POLAR",
+            label="Polar",
+            unit="V",
+            parameter_class=FormattedSweep,
+            get_parser=self._parse_polar_data,
+            vals=Arrays(shape=(self.parent.points,), valid_types=(complex,)),
+        )
+
+    @staticmethod
+    def _parse_polar_data(data: Sequence[float]) -> np.ndarray:
+        """
+        Parse the 2*n-length flat array coming from the instrument
+        and convert to n-length array of complex numbers
+        """
+        pairs = np.array([data[::2], data[1::2]]).T
+        return np.array([complex(*pair) for pair in pairs])
 
     def run_sweep(self) -> str:
         """
@@ -229,7 +310,8 @@ class PNATrace(InstrumentChannel):
             elif source == "EXT":
                 msg += "The trigger source is external. Is the trigger " \
                        "source functional?"
-            logger.warning(msg)
+            self.log.warning(msg)
+            raise
 
         # Return previous mode, incase we want to restore this
         return prev_mode
@@ -293,6 +375,9 @@ class PNABase(VisaInstrument):
         self.min_freq = min_freq
         self.max_freq = max_freq
 
+        self.log.info("Initializing %s with power range %r-%r, freq range %r-%r.",
+                      name, min_power, max_power, min_freq, max_freq)
+
         #Ports
         ports = ChannelList(self, "PNAPorts", PNAPort)
         for port_num in range(1, nports+1):
@@ -300,8 +385,16 @@ class PNABase(VisaInstrument):
                            min_power, max_power)
             ports.append(port)
             self.add_submodule(f"port{port_num}", port)
-        ports.lock()
-        self.add_submodule("ports", ports)
+        self.add_submodule("ports", ports.to_channel_tuple())
+
+        # RF output
+        self.add_parameter(
+            "output",
+            label="RF Output",
+            get_cmd=":OUTPut?",
+            set_cmd=":OUTPut {}",
+            val_mapping=create_on_off_val_mapping(on_val="1", off_val="0"),
+        )
 
         # Drive power
         self.add_parameter('power',
@@ -369,6 +462,14 @@ class PNABase(VisaInstrument):
                            unit='Hz',
                            vals=Numbers(min_value=min_freq,
                                         max_value=max_freq))
+        self.add_parameter('cw',
+                           label='CW Frequency',
+                           get_cmd='SENS:FREQ:CW?',
+                           get_parser=float,
+                           set_cmd='SENS:FREQ:CW {}',
+                           unit='Hz',
+                           vals=Numbers(min_value=min_freq,
+                                        max_value=max_freq))
 
         # Number of points in a sweep
         self.add_parameter('points',
@@ -401,6 +502,13 @@ class PNABase(VisaInstrument):
                            get_cmd='SENS:SWE:MODE?',
                            set_cmd='SENS:SWE:MODE {}',
                            vals=Enum("HOLD", "CONT", "GRO", "SING"))
+        # Sweep Type
+        self.add_parameter('sweep_type',
+                           label='Type',
+                           get_cmd='SENS:SWE:TYPE?',
+                           set_cmd='SENS:SWE:TYPE {}',
+                           vals=Enum('LIN', 'LOG', 'POW', 'CW', 'SEGM', 'PHAS'))
+
         # Group trigger count
         self.add_parameter('group_trigger_count',
                            get_cmd="SENS:SWE:GRO:COUN?",
@@ -413,6 +521,32 @@ class PNABase(VisaInstrument):
                            set_cmd="TRIG:SOUR {}",
                            vals=Enum("EXT", "IMM", "MAN"))
 
+        # Axis Parameters
+        self.add_parameter('frequency_axis',
+                           unit='Hz',
+                           label="Frequency",
+                           parameter_class=PNAAxisParameter,
+                           startparam=self.start,
+                           stopparam=self.stop,
+                           pointsparam=self.points,
+                           vals=Arrays(shape=(self.points,)))
+        self.add_parameter('frequency_log_axis',
+                           unit='Hz',
+                           label="Frequency",
+                           parameter_class=PNALogAxisParamter,
+                           startparam=self.start,
+                           stopparam=self.stop,
+                           pointsparam=self.points,
+                           vals=Arrays(shape=(self.points,)))
+        self.add_parameter('time_axis',
+                           unit='s',
+                           label="Time",
+                           parameter_class=PNATimeAxisParameter,
+                           startparam=None,
+                           stopparam=self.sweep_time,
+                           pointsparam=self.points,
+                           vals=Arrays(shape=(self.points,)))
+
         # Traces
         self.add_parameter('active_trace',
                            label='Active Trace',
@@ -464,8 +598,10 @@ class PNABase(VisaInstrument):
         # if no traces were selected.
         try:
             active_trace = self.active_trace()
-        except VisaIOError as e:
-            if e.error_code == errors.StatusCode.error_timeout:
+        except errors.VisaIOError as e:
+            self.log.debug("Exception on querying active trace: %r", e)
+            if e.error_code == constants.StatusCode.error_timeout:
+                self.log.info("No active trace on PNA")
                 active_trace = None
             else:
                 raise
@@ -542,11 +678,11 @@ class PNABase(VisaInstrument):
 
 class PNAxBase(PNABase):
     def _enable_fom(self) -> None:
-        '''
+        """
         PNA-x units with two sources have an enormous list of functions &
         configurations. In practice, most of this will be set up manually on
         the unit, with power and frequency varied in a sweep.
-        '''
+        """
         self.add_parameter('aux_frequency',
                            label='Aux Frequency',
                            get_cmd='SENS:FOM:RANG4:FREQ:CW?',
