@@ -3,25 +3,24 @@
 # the instrument drivers package
 # Version 2.1 QDevil 2020-02-10
 
-from typing import Optional, Sequence, Dict, Any, Tuple, Union
+import logging
 import time
+from collections import namedtuple
+from enum import Enum
+from functools import partial
+from typing import Any, Dict, Optional, Sequence, Tuple, Union
+
 import pyvisa as visa
 from pyvisa.resources.serial import SerialInstrument
-import logging
 
-from functools import partial
-from qcodes.instrument.channel import InstrumentChannel, ChannelList
-from qcodes.instrument.channel import MultiChannelInstrumentParameter
-from qcodes.instrument.visa import VisaInstrument
-from qcodes.utils import validators as vals
-from qcodes.instrument.parameter import ParamRawDataType
-from enum import Enum
-from collections import namedtuple
+from qcodes import validators as vals
+from qcodes.instrument import ChannelList, InstrumentChannel, VisaInstrument
+from qcodes.parameters import MultiChannelInstrumentParameter, ParamRawDataType
 
 LOG = logging.getLogger(__name__)
 
 
-_ModeTuple = namedtuple('Mode', 'v i')
+_ModeTuple = namedtuple('_ModeTuple', 'v i')
 
 
 class Mode(Enum):
@@ -140,7 +139,8 @@ class QDacChannel(InstrumentChannel):
     def snapshot_base(
             self,
             update: Optional[bool] = False,
-            params_to_skip_update: Optional[Sequence[str]] = None) -> Dict:
+            params_to_skip_update: Optional[Sequence[str]] = None
+    ) -> Dict[Any, Any]:
         update_currents = self._parent._update_currents and update
         if update and not self._parent._get_status_performed:
             self._parent._update_cache(update_currents=update_currents)
@@ -232,7 +232,7 @@ class QDac(VisaInstrument):
 
         assert isinstance(handle, SerialInstrument)
         # Communication setup + firmware check
-        handle.baud_rate = 480600
+        handle.baud_rate = 460800
         handle.parity = visa.constants.Parity(0)
         handle.data_bits = 8
         self.set_terminator('\n')
@@ -263,9 +263,8 @@ class QDac(VisaInstrument):
         for i in self._chan_range:
             channel = QDacChannel(self, f'chan{i:02}', i)
             channels.append(channel)
-            self.add_submodule(f'ch{i:02}', channel)
-        channels.lock()
-        self.add_submodule('channels', channels)
+            self.add_submodule(f"ch{i:02}", channel)
+        self.add_submodule("channels", channels.to_channel_tuple())
 
         # Updatechannel  sync port validator according to number of boards
         self._num_syns = max(num_boards-1, 1)
@@ -384,7 +383,7 @@ class QDac(VisaInstrument):
 
                 self._assigned_fgs[chan] = Generator(fg)
                 self._assigned_fgs[chan].t_end = time_end
-                if trigger != 0:
+                if int(trigger) != 0:
                     self._assigned_triggers[fg] = int(trigger)
                 for syn in range(1, self._num_syns+1):
                     self.write(f'syn {syn}')
@@ -421,9 +420,11 @@ class QDac(VisaInstrument):
         self.mode_force(False)
         self._reset_bookkeeping()
 
-    def snapshot_base(self,
-                      update: Optional[bool] = False,
-                      params_to_skip_update: Optional[Sequence[str]] = None) -> Dict:
+    def snapshot_base(
+            self,
+            update: Optional[bool] = False,
+            params_to_skip_update: Optional[Sequence[str]] = None
+    ) -> Dict[Any, Any]:
         update_currents = self._update_currents and update is True
         if update:
             self._update_cache(update_currents=update_currents)
@@ -836,17 +837,18 @@ class QDac(VisaInstrument):
         self._update_cache(update_currents=update_currents)
 
         for ii in range(self.num_chans):
-            line = 'Channel {} \n'.format(ii+1)
-            line += '    Voltage: {} ({}).\n'.format(
-                    self.channels[ii].v.cache(), self.channels[ii].v.unit)
-            line += '    Current: {} ({}).\n'.format(
-                    self.channels[ii].i.cache.get(get_if_invalid=False),
-                                                self.channels[ii].i.unit)
-            line += '    Mode: {}.\n'.format(
-                    self.channels[ii].mode.cache().get_label())
-            line += '    Slope: {} ({}).\n'.format(
-                    self.channels[ii].slope.cache(),
-                    self.channels[ii].slope.unit)
+            line = f"Channel {ii+1} \n"
+            line += "    Voltage: {} ({}).\n".format(
+                self.channels[ii].v.cache(), self.channels[ii].v.unit
+            )
+            line += "    Current: {} ({}).\n".format(
+                self.channels[ii].i.cache.get(get_if_invalid=False),
+                self.channels[ii].i.unit,
+            )
+            line += f"    Mode: {self.channels[ii].mode.cache().get_label()}.\n"
+            line += "    Slope: {} ({}).\n".format(
+                self.channels[ii].slope.cache(), self.channels[ii].slope.unit
+            )
             if self.channels[ii].sync.cache() > 0:
                 line += '    Sync Out: {}, Delay: {} ({}), '\
                         'Duration: {} ({}).\n'.format(
@@ -1069,7 +1071,7 @@ class QDac(VisaInstrument):
             fg = self._assigned_fgs[ch].fg
             if trigger > 0:  # Trigger 0 is not a trigger
                 self._assigned_triggers[fg] = trigger
-            msg += 'wav {} {} {} {}'.format(ch, fg, amplitude, v_startlist[i])
+            msg += f"wav {ch} {fg} {amplitude} {v_startlist[i]}"
             # using staircase = function 4
             nsteps = slow_steps if ch in slow_chans else fast_steps
             repetitions = slow_steps if ch in fast_chans else 1
