@@ -9,6 +9,7 @@ from functools import partial
 from typing import (
     Any,
     Callable,
+    Dict,
     Iterable,
     List,
     Optional,
@@ -20,10 +21,11 @@ from typing import (
 
 import numpy as np
 
-from qcodes import Instrument, InstrumentChannel, IPInstrument, Parameter
-from qcodes.math_utils.field_vector import FieldVector
-from qcodes.utils.deprecate import QCoDeSDeprecationWarning
-from qcodes.utils.validators import Anything, Bool, Enum, Ints, Numbers
+from qcodes.instrument import Instrument, InstrumentChannel, IPInstrument
+from qcodes.math_utils import FieldVector
+from qcodes.parameters import Parameter
+from qcodes.utils import QCoDeSDeprecationWarning
+from qcodes.validators import Anything, Bool, Enum, Ints, Numbers
 
 log = logging.getLogger(__name__)
 
@@ -757,6 +759,10 @@ class AMI430_3D(Instrument):
 
         self._exit_stack = ExitStack()
 
+    def get_idn(self) -> Dict[str, Optional[str]]:
+        idparts = ["American Magnetics", self.name, None, None]
+        return dict(zip(("vendor", "model", "serial", "firmware"), idparts))
+
     def _set_vector_ramp_rate_units(self, val: float) -> float:
         _, common_ramp_rate_units = self._raise_if_not_same_field_and_ramp_rate_units()
         self.vector_ramp_rate.unit = common_ramp_rate_units
