@@ -6,16 +6,17 @@ MSO70000/C/DX Series Digital Oscilloscopes
 import textwrap
 import time
 from functools import partial
-from typing import Union, Callable, cast, Any
+from typing import Any, Callable, Union, cast
 
 import numpy as np
 
-from qcodes import (
-    Instrument, VisaInstrument, InstrumentChannel, ParameterWithSetpoints,
-    ChannelList, Parameter
+from qcodes.instrument import ChannelList, Instrument, InstrumentChannel, VisaInstrument
+from qcodes.parameters import (
+    Parameter,
+    ParameterWithSetpoints,
+    create_on_off_val_mapping,
 )
-from qcodes.utils.helpers import create_on_off_val_mapping
-from qcodes.utils.validators import Enum, Arrays
+from qcodes.validators import Arrays, Enum
 
 
 def strip_quotes(string: str) -> str:
@@ -26,7 +27,7 @@ def strip_quotes(string: str) -> str:
     return string.strip('"')
 
 
-class ModeError(Exception):
+class TektronixDPOModeError(Exception):
     """
     Raise this exception if we are in a wrong mode to
     perform an action
@@ -34,6 +35,12 @@ class ModeError(Exception):
     pass
 
 
+ModeError = TektronixDPOModeError
+"""
+Alias for backwards compatibility
+"""
+
+
 class TektronixDPO7000xx(VisaInstrument):
     """
     QCoDeS driver for the MSO/DPO5000/B, DPO7000/C,
@@ -308,7 +315,7 @@ class TekronixDPOWaveform(InstrumentChannel):
 
         return inner
 
-    def _get_trace_data(self)  -> np.ndarray:
+    def _get_trace_data(self) -> np.ndarray:
 
         self.root_instrument.data.source(self._identifier)
         waveform = self.root_instrument.waveform
@@ -597,7 +604,7 @@ class TektronixDPOHorizontal(InstrumentChannel):
 
     def _set_record_length(self, value: int) -> None:
         if self.mode() != "manual":
-            raise ModeError(
+            raise TektronixDPOModeError(
                 "The record length can only be changed in manual mode"
             )
 
@@ -605,9 +612,7 @@ class TektronixDPOHorizontal(InstrumentChannel):
 
     def _set_scale(self, value: float) -> None:
         if self.mode() == "manual":
-            raise ModeError(
-                "The scale cannot be changed in manual mode"
-            )
+            raise TektronixDPOModeError("The scale cannot be changed in manual mode")
 
         self.write(f"HORizontal:MODE:SCAle {value}")
 
@@ -624,7 +629,7 @@ class TekronixDPOTrigger(InstrumentChannel):
     trigger conditions are met.
 
     A and B triggers can (and typically do) have separate sources.
-    The B trigger condition is based on a time delay or a speciﬁed
+    The B trigger condition is based on a time delay or a specified
     number of events.
 
     See page75, Using A (Main) and B (Delayed) triggers.
@@ -796,7 +801,7 @@ class TektronixDPOMeasurement(InstrumentChannel):
             get_cmd=f"MEASUrement:MEAS{self._measurement_number}:TYPe?",
             set_cmd=self._set_measurement_type,
             get_parser=str.lower,
-            vals=Enum(*[m[0] for m in self.measurements]),
+            vals=Enum(*(m[0] for m in self.measurements)),
             docstring=textwrap.dedent(
                 "Please see page 566-569 of the programmers manual "
                 "for a detailed description of these arguments. "
