@@ -9,24 +9,27 @@ import pytest
 import qcodes as qc
 import qcodes.dataset.descriptions.versioning.serialization as serial
 import qcodes.tests.dataset
-from qcodes import new_data_set, new_experiment
-from qcodes.dataset.data_set import load_by_counter, load_by_id, load_by_run_spec
+from qcodes.dataset import (
+    ConnectionPlus,
+    connect,
+    initialise_database,
+    initialise_or_create_database_at,
+    load_by_counter,
+    load_by_id,
+    load_by_run_spec,
+    new_data_set,
+    new_experiment,
+)
 from qcodes.dataset.descriptions.dependencies import InterDependencies_
 from qcodes.dataset.descriptions.param_spec import ParamSpecBase
 from qcodes.dataset.descriptions.versioning.v0 import InterDependencies
 from qcodes.dataset.guids import parse_guid
-from qcodes.dataset.sqlite.connection import ConnectionPlus, atomic_transaction
-from qcodes.dataset.sqlite.database import (
-    connect,
-    get_db_version_and_newest_available_version,
-    initialise_database,
-    initialise_or_create_database_at,
-)
+from qcodes.dataset.sqlite.connection import atomic_transaction
+from qcodes.dataset.sqlite.database import get_db_version_and_newest_available_version
 
 # pylint: disable=unused-import
 from qcodes.dataset.sqlite.db_upgrades import (
     _latest_available_version,
-    get_user_version,
     perform_db_upgrade,
     perform_db_upgrade_0_to_1,
     perform_db_upgrade_1_to_2,
@@ -37,8 +40,8 @@ from qcodes.dataset.sqlite.db_upgrades import (
     perform_db_upgrade_6_to_7,
     perform_db_upgrade_7_to_8,
     perform_db_upgrade_8_to_9,
-    set_user_version,
 )
+from qcodes.dataset.sqlite.db_upgrades.version import get_user_version, set_user_version
 from qcodes.dataset.sqlite.queries import get_run_description, update_GUIDs
 from qcodes.dataset.sqlite.query_helpers import (
     get_description_map,
