@@ -7,12 +7,11 @@ from pathlib import Path
 import hypothesis.strategies as hst
 import numpy as np
 import pytest
-import xarray
+import xarray as xr
 from hypothesis import HealthCheck, given, settings
 from numpy.testing import assert_almost_equal
 
-from qcodes import load_by_id
-from qcodes.dataset import load_by_run_spec
+from qcodes.dataset import load_by_id, load_by_run_spec
 from qcodes.dataset.data_set_in_memory import DataSetInMem
 from qcodes.dataset.data_set_protocol import DataSetType
 from qcodes.dataset.sqlite.connection import ConnectionPlus, atomic_transaction
@@ -489,6 +488,7 @@ def compare_datasets(ds, loaded_ds):
 
 
 def test_load_from_db_dataset_moved(meas_with_registered_param, DMM, DAC, tmp_path):
+
     Station(DAC, DMM)
     with meas_with_registered_param.run(
         dataset_class=DataSetType.DataSetInMem
@@ -506,7 +506,7 @@ def test_load_from_db_dataset_moved(meas_with_registered_param, DMM, DAC, tmp_pa
 
     export_path = ds.export_info.export_paths["nc"]
 
-    with contextlib.closing(xarray.open_dataset(export_path)) as xr_ds:
+    with contextlib.closing(xr.open_dataset(export_path)) as xr_ds:
         assert xr_ds.attrs["metadata_added_after_export"] == 69
 
     new_path = str(Path(export_path).parent / "someotherfilename.nc")
@@ -533,7 +533,7 @@ def test_load_from_db_dataset_moved(meas_with_registered_param, DMM, DAC, tmp_pa
     ):
         ds.add_metadata("metadata_added_after_move", 696)
 
-    with contextlib.closing(xarray.open_dataset(new_path)) as new_xr_ds:
+    with contextlib.closing(xr.open_dataset(new_path)) as new_xr_ds:
         assert new_xr_ds.attrs["metadata_added_after_export"] == 69
         assert "metadata_added_after_move" not in new_xr_ds.attrs
 
@@ -541,7 +541,7 @@ def test_load_from_db_dataset_moved(meas_with_registered_param, DMM, DAC, tmp_pa
 
     assert loaded_ds.cache.data().keys() == ds.cache.data().keys()
 
-    with contextlib.closing(xarray.open_dataset(new_path)) as new_xr_ds:
+    with contextlib.closing(xr.open_dataset(new_path)) as new_xr_ds:
         assert new_xr_ds.attrs["metadata_added_after_export"] == 69
         assert "metadata_added_after_move" not in new_xr_ds.attrs
 
@@ -555,7 +555,7 @@ def test_load_from_db_dataset_moved(meas_with_registered_param, DMM, DAC, tmp_pa
 
     loaded_ds.add_metadata("metadata_added_after_set_new_netcdf_location", 6969)
 
-    with contextlib.closing(xarray.open_dataset(new_path)) as new_xr_ds:
+    with contextlib.closing(xr.open_dataset(new_path)) as new_xr_ds:
         assert new_xr_ds.attrs["metadata_added_after_export"] == 69
         assert "metadata_added_after_move" not in new_xr_ds.attrs
         assert (
