@@ -3,14 +3,15 @@ import numpy as np
 import pytest
 from hypothesis import HealthCheck, given, settings
 
-from qcodes.dataset.descriptions.detect_shapes import \
-    detect_shape_of_measurement
-from qcodes.instrument.parameter import Parameter
-from qcodes.tests.instrument_mocks import (ArraySetPointParam,
-                                           Multi2DSetPointParam,
-                                           Multi2DSetPointParam2Sizes,
-                                           MultiSetPointParam)
-from qcodes.utils.validators import Arrays
+from qcodes.dataset.descriptions.detect_shapes import detect_shape_of_measurement
+from qcodes.parameters import Parameter
+from qcodes.tests.instrument_mocks import (
+    ArraySetPointParam,
+    Multi2DSetPointParam,
+    Multi2DSetPointParam2Sizes,
+    MultiSetPointParam,
+)
+from qcodes.validators import Arrays
 
 from .conftest import ArrayshapedParam
 
