@@ -3,8 +3,9 @@ import re
 import pytest
 
 import qcodes.instrument_drivers.Keysight.keysightb1500.constants as c
-from qcodes.instrument_drivers.Keysight.keysightb1500.message_builder import \
-    MessageBuilder
+from qcodes.instrument_drivers.Keysight.keysightb1500.message_builder import (
+    MessageBuilder,
+)
 
 
 @pytest.fixture
@@ -13,8 +14,7 @@ def mb():
 
 
 def test_as_csv():
-    from qcodes.instrument_drivers.Keysight.keysightb1500.message_builder \
-        import as_csv
+    from qcodes.instrument_drivers.Keysight.keysightb1500.message_builder import as_csv
 
     assert '1' == as_csv([1])
 
