@@ -1,10 +1,11 @@
+import numpy as np
 import pytest
 
-import numpy as np
-
 import qcodes.instrument.sims as sims
-from qcodes.instrument_drivers.Keysight.Keysight_34465A_submodules import \
-    Keysight_34465A
+from qcodes.instrument_drivers.Keysight.Keysight_34465A_submodules import (
+    Keysight_34465A,
+)
+
 visalib = sims.__file__.replace('__init__.py', 'Keysight_34465A.yaml@sim')
 
 
@@ -108,15 +109,15 @@ def test_set_get_autorange(driver):
 
 
 def test_increase_decrease_range(driver):
-    driver_range_user = driver.ranges[4]
+    driver_range_user = driver.ranges[2]
     driver.increase_range(driver_range_user)
-    assert driver.range.get() == driver.ranges[5]
-    driver.increase_range(driver_range_user, 2)
-    assert driver.range() == driver.ranges[6]
-    driver.decrease_range(driver_range_user)
     assert driver.range() == driver.ranges[3]
+    driver.increase_range(driver_range_user, 2)
+    assert driver.range() == driver.ranges[4]
+    driver.decrease_range(driver_range_user)
+    assert driver.range() == driver.ranges[1]
     driver.decrease_range(driver_range_user, -2)
-    assert driver.range() == driver.ranges[2]
+    assert driver.range() == driver.ranges[0]
     driver_range_user = driver.ranges[3]
     driver.decrease_range(driver_range_user, -2)
     assert driver.range() == driver.ranges[1]
