@@ -1,10 +1,8 @@
-import warnings
-
 import pytest
 import pyvisa as visa
 
 from qcodes.instrument.visa import VisaInstrument
-from qcodes.utils.validators import Numbers
+from qcodes.validators import Numbers
 
 
 class MockVisa(VisaInstrument):
@@ -15,9 +13,8 @@ class MockVisa(VisaInstrument):
                            set_cmd='STAT:{:.3f}',
                            vals=Numbers(-20, 20))
 
-    def set_address(self, address):
-        self.visa_handle = MockVisaHandle()
-        self.visabackend = self.visalib
+    def _open_resource(self, address: str, visalib):
+        return MockVisaHandle(), visalib
 
 
 class MockVisaHandle(visa.resources.MessageBasedResource):
@@ -137,7 +134,7 @@ def test_ask_write_local(mock_visa):
 
 def test_visa_backend(mocker, request):
 
-    rm_mock = mocker.patch('qcodes.instrument.visa.visa.ResourceManager')
+    rm_mock = mocker.patch("qcodes.instrument.visa.pyvisa.ResourceManager")
 
     address_opened = [None]
 
